@@ -8,42 +8,42 @@ Copyright (c) 2021 Sean Brogan
 SPDX-License-Identifier: MIT
 
 """
-import logging
-from enum import Enum
-from collections import deque
+from typing import Optional
 
 from bleson import BDAddress
 
-from advertisement import MopekaAdvertisement
-
-_LOGGER = logging.getLogger(__name__)
+from .advertisement import MopekaAdvertisement
 
 class MopekaSensor(object):
   """ Sensor Object """
 
-  packet_list: deque[MopekaAdvertisement]
   _mac: str
   _bdaddress: BDAddress
+  _last_packet: MopekaAdvertisement
 
   def __init__(self, mac_address:str ):
     self._mac = mac_address
     self._bdaddress = BDAddress(mac_address)
-    self.packet_list = deque(maxlen=3)  #use deque so we get only the most recent
+    self._last_packet = None
 
   def AddReading(self, reading_data: MopekaAdvertisement):
-    self.packet_list.append(reading_data)
+    self._last_packet = reading_data
+
+  def GetReading(self) -> Optional[MopekaAdvertisement]:
+    """ return the most recent packet and clear it """
+    t = self._last_packet
+    self._last_packet = None
+    return t
 
   def __str__(self) -> str:
-    return "{MopekaSensor - MAC ADDRESS: " + str(self._mac) + " Advertisements: " + str(len(self.packet_list)) + "}"
-
-  def Clear(self):
-    """ clear the saved advertisement list """
-    self.packet_list.clear()
+    return "{MopekaSensor - MAC ADDRESS: " + str(self._mac) + " " + str(self._last_packet) + "}"
 
   def Dump(self):
     print(f"MopekaSensor:")
     print(f"  - MAC: {self._mac}")
-    print(f"  - Advertisements ({len(self.packet_list)})")
-    for ad in self.packet_list:
-      ad.Dump()
-    print()
\ No newline at end of file
+    a = self._last_packet
+    if a:
+      print("  - Advertisement: ")
+      a.Dump()
+    else:
+      print(f"  - Advertisement: None")
